%define rname drbd8

Name: drbd8-tools
Summary: Distributed Redundant Block Device utilities
Version: 8.2.6
Release: alt1.M40.2
Source0: %rname-%version.tar
License: GPL
Group: System/Kernel and hardware
Url: http://www.drbd.org/

BuildRequires: docbook-utils flex

Conflicts: drbd-tools

Packager: Eugene Prokopiev <enp@altlinux.ru>

%description
Drbd is a distributed replicated block device. It mirrors a
block device over the network to another machine. Think of it
as networked raid 1. It is a building block for setting up
high availability (HA) clusters.

This package contains the programs that will control the drbd kernel module
provided in kernel-source-drbd. You will need a clustering service (such as
heartbeat) to fully implement it.

Authors:
--------
    Philipp Reisner <philipp.reisner at linbit dot com>
    Lars Ellenberg  <l.g.e at web dot de>

%package -n kernel-source-%rname-%version
Summary: Kernel source for DRBD
Group: Development/Kernel

BuildRequires(pre): kernel-build-tools

%description -n kernel-source-%rname-%version
This is the source of the kernel-dependant driver for DRBD.

%prep
%setup -q -n %rname-%version
%__cp -a drbd kernel-source-%rname-%version
%__tar -cj -f kernel-source-%rname-%version.tar.bz2 \
    kernel-source-%rname-%version

%build
%__make CFLAGS="%optflags" drbd/drbd_buildtag.c
for dir in user scripts documentation; do
    %__make CFLAGS="%optflags -I../drbd" PREFIX=%buildroot/ MANDIR=%_mandir -C "$dir"
done
# remake doc
%__make PREFIX=%buildroot/ MANDIR=%_mandir doc

%install
%__mkdir_p %kernel_srcdir
%__install -p -m644 kernel-source-%rname-%version.tar.bz2 %kernel_srcdir/

for dir in user scripts documentation; do
    %__make PREFIX=%buildroot/ MANDIR=%_mandir -C "$dir" install
done
%__install -pD -m755 scripts/drbd %buildroot%_initdir/drbd

# and I only want to install a hint to the example conf
#
cat <<EOF > %buildroot%_sysconfdir/drbd.conf
#
# please have a a look at the example configuration file in
# %_docdir/%name-%version/drbd.conf
#
EOF

%__mkdir_p %buildroot%_sysconfdir/default
cat <<EOF > %buildroot%_sysconfdir/default/%rname
DEFAULTFILE="%_sysconfdir/default/drbd"
DRBDADM="/sbin/drbdadm"
PROC_DRBD="/proc/drbd"
MODPROBE="/sbin/modprobe"
RMMOD="/sbin/rmmod"
UDEV_TIMEOUT=10
ADD_MOD_PARAM=""
EOF

%files
/sbin/drbdsetup
/sbin/drbdadm
/sbin/drbdmeta
%_initdir/drbd
%config(noreplace) %_sysconfdir/drbd.conf
%_sysconfdir/default/%rname
%_libexecdir/*
%_man8dir/*
%_man5dir/*
%doc scripts/drbd.conf
%doc COPYING
%doc README
%doc ChangeLog

%files -n kernel-source-%rname-%version
%_usrsrc/*

%changelog
* Tue Sep 09 2008 Eugene Prokopiev <enp@altlinux.ru> 8.2.6-alt1.M40.2
- backport to M40

* Tue Sep 09 2008 Eugene Prokopiev <enp@altlinux.ru> 8.2.6-alt2
- fix x86_64 build

* Mon Sep 08 2008 Eugene Prokopiev <enp@altlinux.ru> 8.2.6-alt1
- new version
- new repo scheme 
- some cleanup:
  + remove rpm-build-linux-ha support
  + use upstream initscript

* Sun May 18 2008 L.A. Kostis <lakostis@altlinux.ru> 0.7.25-alt1.git18022008
- use GIT fe0c05d shapshot.

* Sun May 18 2008 L.A. Kostis <lakostis@altlinux.ru> 0.7.25-alt1
- 0.7.25.

* Sat Dec 02 2006 L.A. Kostis <lakostis@altlinux.ru> 0.7.22-alt2
- add dependency to linux-ha-common.
- update ha resources.
- remove unwanted kernel version checks during -tools install.

* Fri Nov 10 2006 L.A. Kostis <lakostis@altlinux.ru> 0.7.22-alt1
- 0.7.22.

* Sun Sep 17 2006 L.A. Kostis <lakostis@altlinux.ru> 0.7.21-alt1
- 0.7.21.

* Sun Jul 09 2006 LAKostis <lakostis at altlinux.org> 0.7.20-alt1
- 0.7.20.

* Sun Jun 18 2006 LAKostis <lakostis at altlinux.org> 0.7.19-alt1.1
- imported .spec to git.

* Mon Jun 05 2006 LAKostis <lakostis at altlinux.org> 0.7.19-alt1
- 0.7.19.

* Tue May 09 2006 LAKostis <lakostis at altlinux.org> 0.7.18-alt1.1
- fixed typo in post (see #9534).

* Fri Apr 28 2006 LAKostis <lakostis at altlinux.org> 0.7.18-alt1
- 0.7.18.

* Mon Apr 24 2006 LAKostis <lakostis at altlinux.org> 0.7.17-alt2
- Add drbd nodes only for kernels < 2.6 due udev.

* Sat Apr 22 2006 LAKostis <lakostis at altlinux.org> 0.7.17-alt1.2
- Add condrestart/condreload to init.d script.

* Fri Apr 21 2006 LAKostis <lakostis at altlinux.org> 0.7.17-alt1.1
- Apply patch fixing drbd unconfigured state after startup
  when using udevd.

* Sun Apr 16 2006 LAKostis <lakostis at altlinux.org> 0.7.17-alt1
- 0.7.17.

* Fri Feb 24 2006 LAKostis <lakostis at altlinux.org> 0.7.16-alt1
- 0.7.16.

* Fri Jan 06 2006 LAKostis <lakostis at altlinux.org> 0.7.15-alt1
- 0.7.15.

* Sun Oct 30 2005 LAKostis <lakostis at altlinux.org> 0.7.14-alt1
- initial build for Sisyphus.
- add some defaults from debian package.
- spec based on template from source package.
